<?php
//##copyright##

class iaReviewComments extends abstractPlugin
{
	protected static $_table = 'reviews_comments';
	protected static $_tableClicks = 'reviews_clicks';


	public static function getTableClicks($prefix = false)
	{
		return ($prefix ? INTELLI_DBPREFIX : '') . self::$_tableClicks;
	}

	public function get($fields = false, $condition = '', $start = 0, $limit = null)
	{
		$stmtFields = (!$fields) ? 't1.*' : $fields;

		if (is_array($fields))
		{
			$stmtFields = '';
			foreach ($fields as $key => $field)
			{
				$stmtFields .= is_int($key)
					? 't1.`' . $field . '`'
					: sprintf('%s `%s`', is_numeric($field) ? $field : '`' . $field . '`', $key);
				$stmtFields .= ', ';
			}
			$stmtFields = substr($stmtFields, 0, -2);
		}

		if ($condition)
		{
			$condition = ' WHERE ' . $condition;
		}
		if ($limit && stripos($condition, 'limit') === false)
		{
			$condition .= ' LIMIT ' . $start . ', ' . $limit;
		}

		$sql = "SELECT " . $stmtFields . ", IF(t1.`member_id` != 0, t2.`fullname`, '" . iaLanguage::get('guest') . "') `author` FROM `" . self::getTable(true) . "` t1 "
			. "LEFT JOIN `" . $this->iaDb->prefix . "members` t2 ON t1.member_id = t2.id "
			. $condition;

		return $this->iaDb->getAll($sql);
	}

	public function updateNum($reviews = array(), $num = 0)
	{
		foreach($reviews as $reviewId)
		{
			$this->iaDb->update(array('id' => $reviewId), '', array('comments' => '`comments` + ' . $num), self::getTableClicks());
		}
	}

	public function gridRead($params, $columns, array $filterParams = array(), array $persistentConditions = array())
	{
		$params || $params = array();

		$start = isset($params['start']) ? (int)$params['start'] : 0;
		$limit = isset($params['limit']) ? (int)$params['limit'] : 15;

		$sort = $params['sort'];
		$dir = in_array($params['dir'], array(iaDb::ORDER_ASC, iaDb::ORDER_DESC)) ? $params['dir'] : iaDb::ORDER_ASC;
		$order = ($sort && $dir) ? " ORDER BY `{$sort}` {$dir}" : '';

		$where = $values = array();
		foreach ($filterParams as $name => $type)
		{
			if (isset($params[$name]) && $params[$name])
			{
				$value = iaSanitize::sql($params[$name]);

				switch ($type)
				{
					case 'equal':
						$where[] = sprintf('`%s` = :%s', $name, $name);
						$values[$name] = $value;
						break;
					case 'like':
						$where[] = sprintf('`%s` LIKE :%s', $name, $name);
						$values[$name] = '%' . $value . '%';
				}
			}
		}

		$where = array_merge($where, $persistentConditions);
		$where || $where[] = iaDb::EMPTY_CONDITION;
		$where = implode(' AND ', $where);
		$this->iaDb->bind($where, $values);

		if (is_array($columns))
		{
			$columns = array_merge(array('id', 'delete' => 1), $columns);
		}

		$data = $this->get($columns, $where . $order, $start, $limit);

		return array(
			'data' => $data,
			'total' => (int)$this->iaDb->one(iaDb::STMT_COUNT_ROWS, $where, self::getTable())
		);
	}

	public function gridUpdate($params)
	{
		if (isset($params['status']))
		{
			$reviews = $this->iaDb->onefield('click_id', '`id` IN (' . implode(',', $params['id']) . ')', 0, null, self::getTable());
			$this->updateNum($reviews, ($params['status'] == 'active' ? 1 : -1));
		}

		return parent::gridUpdate($params);
	}

	public function gridDelete($params)
	{
		foreach ($params['id'] as $id)
		{
			$comment = $this->iaDb->row('click_id, status', iaDb::convertIds($id), self::getTable());

			if ('active' == $comment['status'])
			{
				$this->updateNum(array($comment['click_id']), -1);
			}
		}

		return parent::gridDelete($params);
	}
}